==> mpst-seq-0.0.10.crate: mpst-seq-0.0.10/src/lib.rs <==
use proc_macro_hack::proc_macro_hack;

pub use mpst_seq_proc::baking;
pub use mpst_seq_proc::baking_with_enum;
pub use mpst_seq_proc::broadcast_cancel;
pub use mpst_seq_proc::checking;
pub use mpst_seq_proc::choose_mpst_create_multi_to_all;
pub use mpst_seq_proc::choose_mpst_multi_cancel_to_all;
pub use mpst_seq_proc::choose_mpst_multi_http_to_all;
pub use mpst_seq_proc::choose_mpst_multi_to_all;
pub use mpst_seq_proc::close_mpst;
pub use mpst_seq_proc::close_mpst_cancel;
pub use mpst_seq_proc::close_mpst_check_cancel;
pub use mpst_seq_proc::create_broadcast_role_short;
pub use mpst_seq_proc::create_choose_mpst_session_multi_left;
pub use mpst_seq_proc::create_choose_mpst_session_multi_right;
pub use mpst_seq_proc::create_choose_type_multi;
pub use mpst_seq_proc::create_fn_choose_mpst_cancel_multi_to_all_bundle;
pub use mpst_seq_proc::create_fn_choose_mpst_multi_to_all_bundle;
pub use mpst_seq_proc::create_meshedchannels;
pub use mpst_seq_proc::create_normal_role_short;
pub use mpst_seq_proc::create_offer_mpst_session_multi;
pub use mpst_seq_proc::create_offer_type_multi;
pub use mpst_seq_proc::create_recv_http_session;
pub use mpst_seq_proc::create_recv_mpst_session;
pub use mpst_seq_proc::create_send_check_cancel;
pub use mpst_seq_proc::create_send_http_session;
pub use mpst_seq_proc::create_send_mpst_cancel;
pub use mpst_seq_proc::create_send_mpst_session;
pub use mpst_seq_proc::fork_mpst_multi;
pub use mpst_seq_proc::recv_all_aux_simple;
pub use mpst_seq_proc::recv_aux_simple;
pub use mpst_seq_proc::recv_mpst;
pub use mpst_seq_proc::send_aux_simple;
pub use mpst_seq_proc::send_cancel;
pub use mpst_seq_proc::send_mpst;

#[proc_macro_hack]
pub use mpst_seq_proc::e_recv_aux_simple;

#[proc_macro_hack]
pub use mpst_seq_proc::e_recv_all_aux_simple;

#[proc_macro_hack]
pub use mpst_seq_proc::e_send_aux_simple;

#[proc_macro_hack]
pub use mpst_seq_proc::e_send_cancel;

#[proc_macro_hack]
pub use mpst_seq_proc::e_broadcast_cancel;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_normal_role_short;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_broadcast_role_short;

#[proc_macro_hack]
pub use mpst_seq_proc::e_baking;

#[proc_macro_hack]
pub use mpst_seq_proc::e_close_mpst;

#[proc_macro_hack]
pub use mpst_seq_proc::e_fork_mpst_multi;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_choose_type_multi;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_choose_mpst_session_multi_left;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_choose_mpst_session_multi_right;

#[proc_macro_hack]
pub use mpst_seq_proc::e_choose_mpst_multi_to_all;

#[proc_macro_hack]
pub use mpst_seq_proc::e_choose_mpst_multi_cancel_to_all;

#[proc_macro_hack]
pub use mpst_seq_proc::e_choose_mpst_multi_http_to_all;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_fn_choose_mpst_multi_to_all_bundle;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_fn_choose_mpst_cancel_multi_to_all_bundle;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_offer_type_multi;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_offer_mpst_session_multi;

#[proc_macro_hack]
pub use mpst_seq_proc::e_recv_mpst;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_recv_mpst_session;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_send_check_cancel;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_recv_http_session;

#[proc_macro_hack]
pub use mpst_seq_proc::e_send_mpst;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_send_mpst_session;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_send_http_session;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_send_mpst_cancel;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_meshedchannels;

#[proc_macro_hack]
pub use mpst_seq_proc::e_close_mpst_cancel;

#[proc_macro_hack]
pub use mpst_seq_proc::e_choose_mpst_create_multi_to_all;

#[proc_macro_hack]
pub use mpst_seq_proc::e_baking_with_enum;

#[proc_macro_hack]
pub use mpst_seq_proc::e_checking;

==> mpst-seq-0.1.15.crate: mpst-seq-0.1.15/src/lib.rs <==
use proc_macro_hack::proc_macro_hack;

pub use mpst_seq_proc::choose_mpst_multi_to_all;
pub use mpst_seq_proc::recv_all_aux_simple;
pub use mpst_seq_proc::recv_aux_simple;
pub use mpst_seq_proc::send_aux_simple;

//////////////////////////////////////

pub use mpst_seq_proc::create_broadcast_role_short;
pub use mpst_seq_proc::create_normal_role_short;
pub use mpst_seq_proc::create_offer_mpst_session_multi;
pub use mpst_seq_proc::create_recv_mpst_session;
pub use mpst_seq_proc::create_send_mpst_session;

//////////////////////////////////////

pub use mpst_seq_proc::broadcast_cancel;
pub use mpst_seq_proc::choose_mpst_create_multi_to_all;
pub use mpst_seq_proc::choose_mpst_multi_cancel_to_all;
pub use mpst_seq_proc::close_mpst;
pub use mpst_seq_proc::close_mpst_cancel;
pub use mpst_seq_proc::close_mpst_check_cancel;
pub use mpst_seq_proc::create_choose_mpst_session_multi_left;
pub use mpst_seq_proc::create_choose_mpst_session_multi_right;
pub use mpst_seq_proc::create_choose_type_multi;
pub use mpst_seq_proc::create_fn_choose_mpst_cancel_multi_to_all_bundle;
pub use mpst_seq_proc::create_fn_choose_mpst_multi_to_all_bundle;
pub use mpst_seq_proc::create_meshedchannels;
pub use mpst_seq_proc::create_offer_type_multi;
pub use mpst_seq_proc::create_send_check_cancel;
pub use mpst_seq_proc::create_send_mpst_cancel;
pub use mpst_seq_proc::fork_mpst_multi;
pub use mpst_seq_proc::send_cancel;

//////////////////////////////////////

pub use mpst_seq_proc::close_mpst_interleaved;
pub use mpst_seq_proc::fork_mpst_multi_interleaved;
pub use mpst_seq_proc::fork_mpst_multi_solo;

//////////////////////////////////////

pub use mpst_seq_proc::choose_mpst_multi_http_to_all;
pub use mpst_seq_proc::create_recv_http_session;
pub use mpst_seq_proc::create_send_http_session;

//////////////////////////////////////

pub use mpst_seq_proc::checking;

//////////////////////////////////////

pub use mpst_seq_proc::baking;
pub use mpst_seq_proc::baking_interleaved_with_enum_and_cancel;
pub use mpst_seq_proc::baking_with_cancel;
pub use mpst_seq_proc::baking_with_enum;
pub use mpst_seq_proc::baking_with_enum_and_cancel;

//////////////////////////////////////

#[proc_macro_hack]
pub use mpst_seq_proc::e_recv_aux_simple;

#[proc_macro_hack]
pub use mpst_seq_proc::e_recv_all_aux_simple;

#[proc_macro_hack]
pub use mpst_seq_proc::e_send_aux_simple;

#[proc_macro_hack]
pub use mpst_seq_proc::e_choose_mpst_multi_to_all;

//////////////////////////////////////

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_broadcast_role_short;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_normal_role_short;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_offer_mpst_session_multi;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_recv_mpst_session;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_send_mpst_session;

//////////////////////////////////////

#[proc_macro_hack]
pub use mpst_seq_proc::e_send_cancel;

#[proc_macro_hack]
pub use mpst_seq_proc::e_broadcast_cancel;

#[proc_macro_hack]
pub use mpst_seq_proc::e_close_mpst;

#[proc_macro_hack]
pub use mpst_seq_proc::e_fork_mpst_multi;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_choose_type_multi;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_choose_mpst_session_multi_left;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_choose_mpst_session_multi_right;

#[proc_macro_hack]
pub use mpst_seq_proc::e_choose_mpst_multi_cancel_to_all;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_fn_choose_mpst_multi_to_all_bundle;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_fn_choose_mpst_cancel_multi_to_all_bundle;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_offer_type_multi;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_send_check_cancel;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_send_mpst_cancel;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_meshedchannels;

#[proc_macro_hack]
pub use mpst_seq_proc::e_close_mpst_cancel;

#[proc_macro_hack]
pub use mpst_seq_proc::e_choose_mpst_create_multi_to_all;

//////////////////////////////////////

#[proc_macro_hack]
pub use mpst_seq_proc::e_fork_mpst_multi_solo;

#[proc_macro_hack]
pub use mpst_seq_proc::e_close_mpst_interleaved;

#[proc_macro_hack]
pub use mpst_seq_proc::e_fork_mpst_multi_interleaved;

//////////////////////////////////////

#[proc_macro_hack]
pub use mpst_seq_proc::e_choose_mpst_multi_http_to_all;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_send_http_session;

#[proc_macro_hack]
pub use mpst_seq_proc::e_create_recv_http_session;

//////////////////////////////////////

#[proc_macro_hack]
pub use mpst_seq_proc::e_checking;

//////////////////////////////////////

#[proc_macro_hack]
pub use mpst_seq_proc::e_baking;

#[proc_macro_hack]
pub use mpst_seq_proc::e_baking_with_enum;

#[proc_macro_hack]
pub use mpst_seq_proc::e_baking_with_cancel;

#[proc_macro_hack]
pub use mpst_seq_proc::e_baking_with_enum_and_cancel;

#[proc_macro_hack]
pub use mpst_seq_proc::e_baking_interleaved_with_enum_and_cancel;
